@@ -169,6 +169,9 @@ renv_dependencies_impl <- function(
   if (renv_tests_running() && missing(errors))
     errors <- "ignored"
 
+  # resolve errors
+  errors <- match.arg(errors)
+
   # check and see if we've pre-computed dependencies for this path, and
   # retrieve those pre-computed dependencies if so
   if (length(path) == 1)
@@ -376,8 +379,8 @@ renv_dependencies_discover <- function(paths, progress, errors) {
 
   # nocov start
   vprintf("Finding R package dependencies ... ")
-  discover <- renv_progress(renv_dependencies_discover_impl, length(paths))
-  deps <- lapply(paths, discover)
+  callback <- renv_progress_callback(renv_dependencies_discover_impl, length(paths))
+  deps <- lapply(paths, callback)
   vwritef("Done!")
 
   bind(deps)
@@ -439,7 +442,8 @@ renv_dependencies_discover_renv_lock <- function(path) {
 
 renv_dependencies_discover_description <- function(path,
                                                    fields = NULL,
-                                                   subdir = NULL)
+                                                   subdir = NULL,
+                                                   project = NULL)
 {
   dcf <- catch(renv_description_read(path = path, subdir = subdir))
   if (inherits(dcf, "error"))
@@ -460,9 +464,13 @@ renv_dependencies_discover_description <- function(path,
   # if this is the DESCRIPTION file for the active project, include
   # Suggests since they're often needed as well. such packages will be
   # considered development dependencies, except for package projects
-  state <- renv_dependencies_state()
   type <- "unknown"
-  if (identical(file.path(state$root, "DESCRIPTION"), path)) {
+  project <-
+    project %||%
+    renv_dependencies_state(key = "root") %||%
+    renv_project_resolve()
+
+  if (renv_path_same(file.path(project, "DESCRIPTION"), path)) {
 
     # collect profile-specific dependencies as well
     profile <- renv_profile_get()
@@ -545,7 +553,13 @@ renv_dependencies_discover_pkgdown <- function(path) {
 
 renv_dependencies_discover_quarto <- function(path) {
   # TODO: other dependencies to parse from quarto?
-  renv_dependencies_list(path, "quarto")
+  #
+  # NOTE: we previously inferred a dependency on the R 'quarto' package here,
+  # but quarto is normally invoked directly (rather than via the package) and
+  # so such a dependency is not strictly necessary.
+  #
+  # https://github.com/rstudio/renv/issues/995
+  renv_dependencies_list_empty()
 }
 
 renv_dependencies_discover_rsconnect <- function(path) {
@@ -736,13 +750,16 @@ renv_dependencies_discover_chunks <- function(path, mode) {
 
     # parse params in header
     header <- contents[[lhs]]
-    params <- renv_dependencies_discover_parse_params(header, type)
+    params <- renv_knitr_options_header(header, type)
 
     # extract chunk contents (preserve newlines for nicer error reporting)
     range <- seq.int(lhs + 1, length.out = rhs - lhs - 1)
     code <- rep.int("", length(contents))
     code[range] <- contents[range]
 
+    # also parse chunk options
+    params <- modifyList(params, renv_knitr_options_chunk(code))
+
     # return list of outputs
     list(params = params, code = code)
 
@@ -796,7 +813,7 @@ renv_dependencies_discover_chunks <- function(path, mode) {
 renv_dependencies_discover_chunks_inline <- function(path, contents) {
 
   pasted <- paste(contents, collapse = "\n")
-  matches <- gregexpr("`r ([^`]+)`", pasted)
+  matches <- gregexpr("`r ([^`]+)`", pasted, perl = TRUE)
   if (identical(c(matches[[1L]]), -1L))
     return(list())
 
@@ -1504,53 +1521,6 @@ renv_dependencies_list_empty <- function() {
 
 }
 
-
-renv_dependencies_discover_parse_params <- function(header, type) {
-
-  engine <- "r"
-  patterns <- renv_knitr_patterns()
-  rest <- sub(patterns[[type]]$chunk.begin, "\\1", header)
-
-  # if this is an R Markdown document, parse the initial engine chunk
-  if (type == "md") {
-    idx <- regexpr("(?:[ ,]|$)", rest)
-    engine <- substring(rest, 1, idx - 1)
-    rest <- sub("^,*\\s*", "", substring(rest, idx + 1))
-  }
-
-  # extract an unquoted label
-  label <- ""
-  pattern <- "(^\\s*[^=]+)(,|\\s*$)"
-  matches <- regexec(pattern, rest)[[1]]
-  if (!identical(c(matches), -1L)) {
-    submatches <- regmatches(rest, list(matches))[[1]]
-    label <- trimws(submatches[[2L]])
-    rest <- substring(rest, matches[[3L]] + 1L)
-  }
-
-  params <- catch(parse(text = sprintf("alist(%s)", rest))[[1]])
-  if (inherits(params, "error"))
-    return(list(engine = engine))
-
-  # inject the label back in
-  names(params) <- names(params) %||% rep.int("", length(params))
-  if (length(params) > 1 && names(params)[[2L]] == "")
-    names(params)[[2L]] <- "label"
-
-  # fix up 'label' if it's a missing value
-  if (identical(params[["label"]], quote(expr = )))
-    params[["label"]] <- NULL
-
-  if (is.null(params[["label"]]) && nzchar(label))
-    params[["label"]] <- label
-
-  if (is.null(params[["engine"]]))
-    params[["engine"]] <- engine
-
-  eval(params, envir = parent.frame())
-
-}
-
 renv_dependencies_require <- function(package, type) {
 
   if (requireNamespace(package, quietly = TRUE))
@@ -1569,8 +1539,9 @@ renv_dependencies_require <- function(package, type) {
 
 }
 
-renv_dependencies_state <- function() {
-  renv_global_get("dependencies.state")
+renv_dependencies_state <- function(key = NULL) {
+  state <- renv_global_get("dependencies.state")
+  if (is.null(key)) state else state[[key]]
 }
 
 renv_dependencies_begin <- function(root = NULL) {
