@@ -23,6 +23,9 @@ download <- function(url, destfile, type = NULL, quiet = FALSE, headers = NULL)
     if (inherits(result, "error"))
       renv_download_error(result, "%s", conditionMessage(result))
 
+    if (!file.exists(destfile))
+      renv_download_error(url, "%s does not exist", renv_path_pretty(destfile))
+
     return(destfile)
 
   }
@@ -100,6 +103,13 @@ download <- function(url, destfile, type = NULL, quiet = FALSE, headers = NULL)
   # move the file to the requested location
   renv_file_move(tempfile, destfile)
 
+  # one final sanity check
+  if (!file.exists(destfile)) {
+    fmt <- "could not move %s to %s"
+    msg <- sprintf(fmt, renv_path_pretty(tempfile), renv_path_pretty(destfile))
+    renv_download_error(url, msg)
+  }
+
   # and return path to successfully retrieved file
   destfile
 
@@ -115,6 +125,12 @@ renv_download_impl <- function(url, destfile, type = NULL, request = "GET", head
   url      <- chartr("\\", "/", url)
   destfile <- chartr("\\", "/", destfile)
 
+  # check that the destination file is writable
+  if (!renv_file_writable(destfile)) {
+    fmt <- "destination path '%s' is not writable; cannot proceed"
+    stopf(fmt, renv_path_pretty(destfile))
+  }
+
   # select the appropriate downloader
   downloader <- switch(
     renv_download_method(),
@@ -300,10 +316,10 @@ renv_download_curl <- function(url, destfile, type, request, headers) {
 
   for (entry in userconfig)
     if (file.exists(entry))
-      args$push("--config", shQuote(entry))
+      args$push("--config", renv_shell_path(entry))
 
   # add in our own config file (the actual request)
-  args$push("--config", shQuote(configfile))
+  args$push("--config", renv_shell_path(configfile))
 
   # perform the download
   output <- suppressWarnings(
@@ -394,19 +410,19 @@ renv_download_wget <- function(url, destfile, type, request, headers) {
   if (length(extra))
     args$push(extra)
 
-  args$push("--config", shQuote(configfile))
+  args$push("--config", renv_shell_path(configfile))
 
   # NOTE: '-O' does not write headers to file; we need to manually redirect
   # in that case
   status <- if (request == "HEAD") {
     args$push("--server-response", "--spider")
-    args$push(">", shQuote(destfile), "2>&1")
+    args$push(">", renv_shell_path(destfile), "2>&1")
     cmdline <- paste("wget", paste(args$data(), collapse = " "))
     return(suppressWarnings(system(cmdline)))
   }
 
-  args$push("-O", shQuote(destfile))
-  args$push(shQuote(url))
+  args$push("-O", renv_shell_path(destfile))
+  args$push(renv_shell_quote(url))
 
   output <- suppressWarnings(
     system2("wget", args$data(), stdout = TRUE, stderr = TRUE)
