@@ -74,6 +74,18 @@ renv_retrieve_impl <- function(package) {
     renv_scope_bioconductor(project = project)
   }
 
+  # if this is a package from R-Forge, activate its repository
+  if (source %in% c("repository")) {
+    repository <- record$Repository %||% ""
+    if (tolower(repository) %in% c("rforge", "r-forge")) {
+      repos <- getOption("repos")
+      if (!"R-Forge" %in% names(repos)) {
+        repos[["R-Forge"]] <- "https://R-Forge.R-project.org"
+        renv_scope_options(repos = repos)
+      }
+    }
+  }
+
   # if the record doesn't declare the package version,
   # treat it as a request for the latest version on CRAN
   # TODO: should make this behavior configurable
@@ -96,14 +108,26 @@ renv_retrieve_impl <- function(package) {
   # TODO: handle more explicit dependency requirements
   # TODO: report to the user if they have explicitly requested
   # installation of this package version despite it being incompatible
-  compat <- renv_retrieve_incompatible(record)
+  compat <- renv_retrieve_incompatible(package, record)
   if (NROW(compat)) {
 
+    # get the latest available package version
     replacement <- renv_available_packages_latest(package)
     if (is.null(replacement))
       stopf("package '%s' is not available", package)
 
-    renv_retrieve_incompatible_report(record, replacement, compat)
+    # if it's not compatible, then we might need to try again with
+    # a source version (assuming type = "both")
+    pkgtype <- getOption("pkgType")
+    if (identical(pkgtype, "both")) {
+      iscompat <- renv_retrieve_incompatible(package, replacement)
+      if (NROW(iscompat)) {
+        replacement <- renv_available_packages_latest(package, type = "source")
+      }
+    }
+
+    # report if we couldn't find a compatible package
+    renv_retrieve_incompatible_report(package, record, replacement, compat)
     record <- replacement
 
   }
@@ -111,7 +135,7 @@ renv_retrieve_impl <- function(package) {
   if (!renv_restore_rebuild_required(record)) {
 
     # if we have an installed package matching the requested record, finish early
-    path <- renv_restore_find(record)
+    path <- renv_restore_find(package, record)
     if (file.exists(path))
       return(renv_retrieve_successful(record, path, install = FALSE))
 
@@ -597,8 +621,10 @@ renv_retrieve_url <- function(record) {
 }
 
 renv_retrieve_repos_archive_name <- function(record, type = "source") {
-  ext <- renv_package_ext(type)
-  paste0(record$Package, "_", record$Version, ext)
+  record$File %||% {
+    ext <- renv_package_ext(type)
+    paste0(record$Package, "_", record$Version, ext)
+  }
 }
 
 renv_retrieve_repos_mran <- function(record) {
@@ -704,12 +730,21 @@ renv_retrieve_repos_archive_path <- function(repo, record) {
   # associated repository
   formatters <- list(
 
+    # default CRAN format
     function(repo, record) {
       with(record, file.path(repo, "src/contrib/Archive", Package))
     },
 
+    # format used by Artifactory
+    # https://github.com/rstudio/renv/issues/602
     function(repo, record) {
       with(record, file.path(repo, "src/contrib/Archive", Package, Version))
+    },
+
+    # format used by Nexus
+    # https://github.com/rstudio/renv/issues/595
+    function(repo, record) {
+      with(record, file.path(repo, "src/contrib"))
     }
 
   )
@@ -761,6 +796,11 @@ renv_retrieve_repos_impl <- function(record,
     if (!is.null(entry$Path) && !is.na(entry$Path))
       repo <- file.path(repo, entry$Path)
 
+    # update the tarball name if it was declared
+    file <- entry$File
+    if (!is.null(file))
+      name <- file
+
   }
 
   url <- file.path(repo, name)
@@ -944,19 +984,39 @@ renv_retrieve_missing_record <- function(package) {
   #   2. request a package + version to be retrieved,
   #   3. hard error
   #
-  renv_available_packages_latest(package)
+  record <- renv_available_packages_latest(package)
+  if (!is.null(record))
+    return(record)
+
+  fmt <- heredoc("
+    renv was unable to find a compatible version of package '%1$s'.
+
+    The latest-available version %1$s is '%2$s', but that version
+    does not appear to be compatible with this version of R.
+
+    You may need to manually re-install a different version of '%1$s'.
+  ")
+
+  entry <- renv_available_packages_entry(package, type = "source")
+  version <- entry$Version %||% "<unknown>"
+
+  msg <- sprintf(fmt, package, version)
+  writeLines(msg)
+
+  stopf("failed to find a compatible version of the '%s' package", package)
 
 }
 
 # check to see if this requested record is incompatible
 # with the set of required dependencies recorded thus far
 # during the package retrieval process
-renv_retrieve_incompatible <- function(record) {
+renv_retrieve_incompatible <- function(package, record) {
 
   state <- renv_restore_state()
+  record <- renv_record_validate(package, record)
 
   # check and see if the installed version satisfies all requirements
-  requirements <- state$requirements[[record$Package]]
+  requirements <- state$requirements[[package]]
   if (is.null(requirements))
     return(NULL)
 
@@ -985,21 +1045,18 @@ renv_retrieve_incompatible <- function(record) {
 
 }
 
-renv_retrieve_incompatible_report <- function(record, replacement, compat) {
+renv_retrieve_incompatible_report <- function(package, record, replacement, compat) {
 
-  # if the record + replacement look the same, bail
-  # (nothing useful to report to user; failure will happen later)
-  same <-
-    record$Package == replacement$Package &&
-    record$Version == replacement$Version
-
-  if (same)
+  # only report if the user explicitly requesting installation of a particular
+  # version of a package, but that package isn't actually compatible
+  state <- renv_restore_state()
+  if (!package %in% state$packages)
     return()
 
   fmt <- "%s (requires %s %s %s)"
   values <- with(compat, sprintf(fmt, Source, Package, Require, Version))
 
-  fmt <- "renv tried to install '%s %s', but the following constraints were not met:"
+  fmt <- "Installation of '%s %s' was requested, but the following constraints are not met:"
   preamble <- with(record, sprintf(fmt, Package, Version))
 
   fmt <- "renv will try to install '%s %s' instead."
