@@ -54,7 +54,7 @@ renv_tests_root_impl <- function(path = getwd()) {
   }
 
   # construct set of paths we'll hunt through
-  slashes <- gregexpr("(?:/|$)", path)[[1]]
+  slashes <- gregexpr("(?:/|$)", path, perl = TRUE)[[1]]
   parts <- substring(path, 1, slashes - 1)
 
   # begin the search
@@ -82,6 +82,8 @@ renv_tests_init_envvars <- function() {
   Sys.unsetenv("RENV_PATHS_ROOT")
   Sys.unsetenv("RENV_PATHS_LIBRARY")
   Sys.unsetenv("RENV_PATHS_LIBRARY_ROOT")
+  Sys.unsetenv("RENV_PATHS_LOCAL")
+  Sys.unsetenv("RENV_PATHS_LOCKFILE")
   Sys.unsetenv("RENV_PATHS_RENV")
 
   Sys.unsetenv("RENV_PYTHON")
@@ -89,6 +91,8 @@ renv_tests_init_envvars <- function() {
   Sys.unsetenv("RETICULATE_PYTHON_ENV")
   Sys.unsetenv("RETICULATE_PYTHON_FALLBACK")
 
+  Sys.setenv(RENV_AUTOLOAD_ENABLED = "FALSE")
+
   envvars <- Sys.getenv()
   configvars <- grep("^RENV_CONFIG_", names(envvars), value = TRUE)
   Sys.unsetenv(configvars)
@@ -128,7 +132,7 @@ renv_tests_init_repos <- function(repopath = NULL) {
   root <- renv_tests_root()
 
   # generate our dummy repository
-  repopath <- repopath %||% tempfile("renv-repos-")
+  repopath <- repopath %||% tempfile("renv-tests-repos-")
   contrib <- file.path(repopath, "src/contrib")
   ensure_directory(contrib)
 
@@ -306,6 +310,16 @@ renv_tests_init_sandbox <- function() {
 
 renv_tests_init_finish <- function() {
 
+  # remove any leftover renv-test- directories in the userdir
+  userdir <- renv_bootstrap_user_dir()
+  libdir <- file.path(userdir, "library")
+  testdirs <- list.files(
+    path = libdir,
+    pattern = "^renv-test-",
+    full.names = TRUE
+  )
+  unlink(testdirs, recursive = TRUE)
+
   # don't perform transactional installs by default for now
   # (causes strange CI failures, especially on Windows?)
   options(renv.config.install.transactional = FALSE)
